@@ -17,9 +17,9 @@ use self::{
   contexts::KubeContext,
   deployments::KubeDeployment,
   key_binding::DEFAULT_KEYBINDING,
-  metrics::{GroupBy, QtyByQualifier},
+  metrics::{GroupBy, KubeNodeMetrics, QtyByQualifier},
   models::{LogsState, ScrollableTxt, StatefulTable, TabsState},
-  nodes::{KubeNode, NodeMetrics},
+  nodes::KubeNode,
   ns::KubeNs,
   pods::{KubeContainer, KubePod},
   replicasets::KubeReplicaSet,
@@ -88,7 +88,7 @@ pub struct Data {
   pub contexts: StatefulTable<KubeContext>,
   pub active_context: Option<KubeContext>,
   pub nodes: StatefulTable<KubeNode>,
-  pub node_metrics: Vec<NodeMetrics>,
+  pub node_metrics: Vec<KubeNodeMetrics>,
   pub namespaces: StatefulTable<KubeNs>,
   pub pods: StatefulTable<KubePod>,
   pub containers: StatefulTable<KubeContainer>,
